@@ -1,12 +1,11 @@
 package org.ovirt.engine.api.restapi.resource;
 
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
-import static org.ovirt.engine.api.restapi.test.util.TestHelper.eqActionParams;
-import static org.ovirt.engine.api.restapi.test.util.TestHelper.eqQueryParams;
+import static org.ovirt.engine.api.restapi.test.util.TestHelper.eqParams;
 import static org.ovirt.engine.api.restapi.test.util.TestHelper.eqSearchParams;
 
 import java.lang.reflect.Method;
@@ -23,21 +22,21 @@ import org.junit.Test;
 import org.ovirt.engine.api.model.BaseResource;
 import org.ovirt.engine.api.model.Fault;
 import org.ovirt.engine.api.model.Link;
-import org.ovirt.engine.core.common.action.VdcActionParametersBase;
-import org.ovirt.engine.core.common.action.VdcActionType;
-import org.ovirt.engine.core.common.action.VdcReturnValueBase;
+import org.ovirt.engine.core.common.action.ActionParametersBase;
+import org.ovirt.engine.core.common.action.ActionReturnValue;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.businessentities.AsyncTaskStatus;
 import org.ovirt.engine.core.common.businessentities.Cluster;
 import org.ovirt.engine.core.common.interfaces.SearchType;
 import org.ovirt.engine.core.common.queries.GetTasksStatusesByTasksIDsParameters;
+import org.ovirt.engine.core.common.queries.QueryParametersBase;
+import org.ovirt.engine.core.common.queries.QueryReturnValue;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.common.queries.SearchParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryParametersBase;
-import org.ovirt.engine.core.common.queries.VdcQueryReturnValue;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.compat.Version;
 
-public abstract class AbstractBackendCollectionResourceTest<R extends BaseResource, Q /* extends IVdcQueryable */, C extends AbstractBackendCollectionResource<R, Q>>
+public abstract class AbstractBackendCollectionResourceTest<R extends BaseResource, Q /* extends Queryable */, C extends AbstractBackendCollectionResource<R, Q>>
         extends AbstractBackendResourceTest<R, Q> {
 
     protected static final String QUERY = "name=s* AND id=*0";
@@ -178,37 +177,39 @@ public abstract class AbstractBackendCollectionResourceTest<R extends BaseResour
     }
 
     protected void setUpQueryExpectations(String query, Object failure) throws Exception {
-        VdcQueryReturnValue queryResult = mock(VdcQueryReturnValue.class);
+        QueryReturnValue queryResult = new QueryReturnValue();
         SearchParameters params = new SearchParameters(prefix + query, searchType);
-        when(queryResult.getSucceeded()).thenReturn(failure == null);
+        queryResult.setSucceeded(failure == null);
         if (failure == null) {
             List<Q> entities = new ArrayList<>();
             for (int i = 0; i < NAMES.length; i++) {
                 entities.add(getEntity(i));
             }
-            when(queryResult.getReturnValue()).thenReturn(entities);
+            queryResult.setReturnValue(entities);
+            when(backend.runQuery(eq(QueryType.Search), eqSearchParams(params))).thenReturn(
+                    queryResult);
         } else {
             if (failure instanceof String) {
-                when(queryResult.getExceptionString()).thenReturn((String) failure);
+                queryResult.setExceptionString((String) failure);
                 setUpL10nExpectations((String)failure);
+                when(backend.runQuery(eq(QueryType.Search), eqSearchParams(params))).thenReturn(
+                        queryResult);
             } else if (failure instanceof Exception) {
-                when(queryResult.getExceptionString()).thenThrow((Exception) failure);
+                when(backend.runQuery(eq(QueryType.Search), eqSearchParams(params))).thenThrow((Exception) failure);
             }
         }
-        when(backend.runQuery(eq(VdcQueryType.Search), eqSearchParams(params))).thenReturn(
-                queryResult);
-        enqueueInteraction(() -> verify(backend, atLeastOnce()).runQuery(eq(VdcQueryType.Search), eqSearchParams(params)));
+        enqueueInteraction(() -> verify(backend, atLeastOnce()).runQuery(eq(QueryType.Search), eqSearchParams(params)));
     }
 
-    protected void setUpCreationExpectations(VdcActionType task,
-                                             Class<? extends VdcActionParametersBase> taskClass,
+    protected void setUpCreationExpectations(ActionType task,
+                                             Class<? extends ActionParametersBase> taskClass,
                                              String[] taskNames,
                                              Object[] taskValues,
                                              boolean valid,
                                              boolean success,
                                              Object taskReturn,
-                                             VdcQueryType query,
-                                             Class<? extends VdcQueryParametersBase> queryClass,
+                                             QueryType query,
+                                             Class<? extends QueryParametersBase> queryClass,
                                              String[] queryNames,
                                              Object[] queryValues,
                                              Object queryReturn) {
@@ -228,8 +229,8 @@ public abstract class AbstractBackendCollectionResourceTest<R extends BaseResour
                                   queryReturn);
     }
 
-    protected void setUpCreationExpectations(VdcActionType task,
-                                             Class<? extends VdcActionParametersBase> taskClass,
+    protected void setUpCreationExpectations(ActionType task,
+                                             Class<? extends ActionParametersBase> taskClass,
                                              String[] taskNames,
                                              Object[] taskValues,
                                              boolean valid,
@@ -237,44 +238,43 @@ public abstract class AbstractBackendCollectionResourceTest<R extends BaseResour
                                              Object taskReturn,
                                              ArrayList<Guid> asyncTasks,
                                              ArrayList<AsyncTaskStatus> asyncStatuses,
-                                             VdcQueryType query,
-                                             Class<? extends VdcQueryParametersBase> queryClass,
+                                             QueryType query,
+                                             Class<? extends QueryParametersBase> queryClass,
                                              String[] queryNames,
                                              Object[] queryValues,
                                              Object queryReturn) {
-        VdcReturnValueBase taskResult = mock(VdcReturnValueBase.class);
-        when(taskResult.isValid()).thenReturn(valid);
+        ActionReturnValue taskResult = new ActionReturnValue();
+        taskResult.setValid(valid);
         if (valid) {
-            when(taskResult.getSucceeded()).thenReturn(success);
+            taskResult.setSucceeded(success);
             if (success) {
-                when(taskResult.getActionReturnValue()).thenReturn(taskReturn);
+                taskResult.setActionReturnValue(taskReturn);
             } else {
-                when(taskResult.getExecuteFailedMessages()).thenReturn(asList(FAILURE));
+                taskResult.setExecuteFailedMessages(asList(FAILURE));
                 setUpL10nExpectations(asList(FAILURE));
             }
         } else {
-            when(taskResult.getValidationMessages()).thenReturn(asList(CANT_DO));
+            taskResult.setValidationMessages(asList(CANT_DO));
             setUpL10nExpectations(asList(CANT_DO));
         }
-        when(taskResult.getHasAsyncTasks()).thenReturn(asyncTasks != null);
         if (asyncTasks != null) {
-            when(taskResult.getVdsmTaskIdList()).thenReturn(asyncTasks);
-            VdcQueryReturnValue monitorResult = mock(VdcQueryReturnValue.class);
-            when(monitorResult.getSucceeded()).thenReturn(success);
-            when(monitorResult.getReturnValue()).thenReturn(asyncStatuses);
-            when(backend.runQuery(eq(VdcQueryType.GetTasksStatusesByTasksIDs),
-                                    eqQueryParams(GetTasksStatusesByTasksIDsParameters.class,
+            taskResult.setVdsmTaskIdList(asyncTasks);
+            QueryReturnValue monitorResult = new QueryReturnValue();
+            monitorResult.setSucceeded(success);
+            monitorResult.setReturnValue(asyncStatuses);
+            when(backend.runQuery(eq(QueryType.GetTasksStatusesByTasksIDs),
+                                    eqParams(GetTasksStatusesByTasksIDsParameters.class,
                                                   addSession(),
                                                   addSession(new Object[]{})))).thenReturn(monitorResult);
-            enqueueInteraction(() -> verify(backend, atLeastOnce()).runQuery(eq(VdcQueryType.GetTasksStatusesByTasksIDs),
-                    eqQueryParams(GetTasksStatusesByTasksIDsParameters.class,
+            enqueueInteraction(() -> verify(backend, atLeastOnce()).runQuery(eq(QueryType.GetTasksStatusesByTasksIDs),
+                    eqParams(GetTasksStatusesByTasksIDsParameters.class,
                             addSession(),
                             addSession(new Object[]{}))));
         }
-        when(backend.runAction(eq(task), eqActionParams(taskClass, addSession(taskNames), addSession(taskValues))))
+        when(backend.runAction(eq(task), eqParams(taskClass, addSession(taskNames), addSession(taskValues))))
                 .thenReturn(taskResult);
         enqueueInteraction(() ->
-                verify(backend, atLeastOnce()).runAction(eq(task), eqActionParams(taskClass, addSession(taskNames), addSession(taskValues))));
+                verify(backend, atLeastOnce()).runAction(eq(task), eqParams(taskClass, addSession(taskNames), addSession(taskValues))));
 
         if (valid && success && query != null) {
             setUpEntityQueryExpectations(query, queryClass, queryNames, queryValues, queryReturn);
